@@ -22,6 +22,7 @@
 #' @param symbol type of symbol in the legend 'line' or 'box'
 #' @export
 #' @examples
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf, col = "grey")
 #' box()
@@ -153,6 +154,7 @@ legendChoro <- function(pos = "topleft",
 #' @param symbol character; 'line' or 'box'
 #' @export
 #' @examples
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf, col = "grey")
 #' box()
@@ -290,6 +292,8 @@ legendTypo <- function(pos = "topleft",
 #' @param values.rnd number of decimal places of the values in 
 #' the legend.
 #' @param col color of symbols.
+#' @param border color of the borders.
+#' @param lwd width of the borders.
 #' @param cex size of the legend. 2 means two times bigger.
 #' @param frame whether to add a frame to the legend (TRUE) or 
 #' not (FALSE).
@@ -297,6 +301,7 @@ legendTypo <- function(pos = "topleft",
 #' styles, "c" stands for compact and "e" for extended.
 #' @export
 #' @examples
+#' library(sp) 
 #' data("nuts2006")
 #' plot(nuts0.spdf)
 #' propSymbolsLayer(spdf = nuts0.spdf, df = nuts0.df, var = "pop2008", 
@@ -321,7 +326,7 @@ legendTypo <- function(pos = "topleft",
 #'                      var = c(min(nuts0.df$pop2008),max(nuts0.df$pop2008)),
 #'                      inches = 0.2, frame = TRUE)
 legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legend", 
-                                title.cex = 0.8, cex = 1,
+                                title.cex = 0.8, cex = 1, border="black", lwd=1,
                                 values.cex = 0.6, var, inches, col="#E84923", 
                                 frame=FALSE, values.rnd=0, style ="c"){
   var <- abs(var)
@@ -367,7 +372,8 @@ legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legen
   }
   
   # Get legend position
-  legcoord <- legpos(pos = pos, x1 = x1, x2 = x2, y1 = y1, y2 = y2,
+  legcoord <- legpos(pos = pos, x1 = x1, x2 = x2, 
+                     y1 = y1, y2 = y2,
                      delta1 = delta1, delta2 = delta2,
                      legend_xsize = legend_xsize, 
                      legend_ysize = legend_ysize)
@@ -384,9 +390,9 @@ legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legen
   if(style=="c"){
     for(i in 1:length(size)){
       symbols(x = xref + size[1], y = yref + size[i], circles = size[i],
-              add = TRUE, bg = col, inches = FALSE)
+              add = TRUE, bg = col, inches = FALSE, lwd=lwd, fg=border)
       segments(xref + size[1], yref + size[i] * 2, xref + size[1] * 2 + delta2,
-               yref + size[i] * 2)
+               yref + size[i] * 2, col = border)
       text(x = xref + size[1] * 2 + delta1, y = yref + size[i] * 2, 
            labels = var[i], adj = c(0,0.5), cex = values.cex)
     }
@@ -398,7 +404,7 @@ legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legen
     jump <- 0
     for(i in length(size):1){
       symbols(x = xref + size[1], y = yref + size[i] + jump, circles = size[i],
-              add = TRUE, bg = col, inches=FALSE)
+              add = TRUE, bg = col, inches=FALSE, lwd=lwd, fg=border)
       text(xref + size[1] + size[i] + delta2 , y = yref + size[i] + jump,
            labels = var[i], adj = c(0,0.5), cex = values.cex)
       jump <- jump + size[i] * 2 + delta2 / 2
@@ -425,6 +431,8 @@ legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legen
 #' @param values.rnd number of decimal places of the values in 
 #' the legend.
 #' @param col color of symbols.
+#' @param border color of the borders.
+#' @param lwd width of the borders.
 #' @param cex size of the legend. 2 means two times bigger.
 #' @param frame whether to add a frame to the legend (TRUE) or 
 #' not (FALSE).
@@ -432,6 +440,7 @@ legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legen
 #' styles, "c" stands for compact and "e" for extended.
 #' @export
 #' @examples
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf)
 #' box()
@@ -443,7 +452,7 @@ legendCirclesSymbols<- function(pos = "topleft", title.txt = "Title of the legen
 #'                      frame=TRUE, values.rnd=0, style ="c")
 #'
 legendSquaresSymbols<- function(pos = "topleft", title.txt = "Title of the legend", 
-                                title.cex = 0.8, cex = 1,
+                                title.cex = 0.8, cex = 1,  border="black", lwd=1,
                                 values.cex = 0.6, var, inches, 
                                 col="red", frame=FALSE, values.rnd=0, style ="c"){
   
@@ -508,9 +517,10 @@ legendSquaresSymbols<- function(pos = "topleft", title.txt = "Title of the legen
   if (style=="c"){
     for(i in 1:length(size)){
       symbols(x = xref + size[i] / 2 + (size[1]-size[i]), y = yref + size[i] / 2, 
-              squares = size[i], add = TRUE, bg = col, inches = FALSE)
+              squares = size[i], add = TRUE, bg = col, inches = FALSE, lwd=lwd, 
+              fg=border)
       segments(xref + size[1], yref + size[i], xref + size[1] + delta2, 
-               yref + size[i])
+               yref + size[i], lwd = 0.7, col = border)
       text(x = xref + size[1] + delta1 ,y = yref + size[i], labels = var[i], 
            adj = c(0,0.5), cex = values.cex)
     }
@@ -522,7 +532,8 @@ legendSquaresSymbols<- function(pos = "topleft", title.txt = "Title of the legen
     jump <- min(size) / 2
     for(i in length(size):1){
       symbols(x = xref + size[i] / 2 + (size[1] - size[i]) / 2, y = yref + jump, 
-              squares = size[i], add = TRUE, bg = col, inches = FALSE)
+              squares = size[i], add = TRUE, bg = col, inches = FALSE, lwd=lwd, 
+              fg=border)
       text(xref + size[i] + (size[1] - size[i]) / 2 + delta2,
            y = yref + jump, var[i], adj = c(0, 0.5), cex = values.cex)
       jump <- size[i] / 2 +  size[i - 1] / 2 + jump  + delta2
@@ -549,6 +560,8 @@ legendSquaresSymbols<- function(pos = "topleft", title.txt = "Title of the legen
 #' @param values.rnd number of decimal places of the values in 
 #' the legend.
 #' @param col color of symbols.
+#' @param border color of the borders.
+#' @param lwd width of the borders.
 #' @param cex size of the legend. 2 means two times bigger.
 #' @param frame whether to add a frame to the legend (TRUE) or 
 #' not (FALSE).
@@ -556,6 +569,7 @@ legendSquaresSymbols<- function(pos = "topleft", title.txt = "Title of the legen
 #' styles, "c" stands for compact and "e" for extended.
 #' @export
 #' @examples
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf)
 #' 
@@ -566,7 +580,8 @@ legendSquaresSymbols<- function(pos = "topleft", title.txt = "Title of the legen
 #'                      col = "purple",
 #'                      values.rnd=0, style ="e")
 legendBarsSymbols<- function(pos = "topleft", title.txt = "Title of the legend", 
-                             title.cex = 0.8, cex = 1, values.cex = 0.6, 
+                             title.cex = 0.8, cex = 1,  border="black", lwd=1,
+                             values.cex = 0.6, 
                              var, inches, col = "red", frame = FALSE, 
                              values.rnd = 0, style = "c"){
   var <- abs(var)
@@ -629,9 +644,10 @@ legendBarsSymbols<- function(pos = "topleft", title.txt = "Title of the legend",
   
   if (style=="c"){
     for(i in 1:length(size)){
-      rect(xref, yref, xref + bwidth, yref + size[i] ,col = col)
+      rect(xref, yref, xref + bwidth, yref + size[i], col = col, lwd = lwd, 
+           border = border)
       segments(xref + bwidth, yref + size[i], 
-               xref + bwidth + delta2, yref + size[i])
+               xref + bwidth + delta2, yref + size[i], lwd = 0.7, col = border)
       text(xref + bwidth + delta1, y = yref + size[i], labels = var[i], 
            adj = c(0,0.5), cex = values.cex)
     }
@@ -642,8 +658,8 @@ legendBarsSymbols<- function(pos = "topleft", title.txt = "Title of the legend",
   if (style=="e"){
     jump <- 0
     for(i in length(size):1){
-      rect(xref, yref + jump, xref + bwidth, yref + size[i] + jump,
-           col = col)
+      rect(xref, yref + jump, xref + bwidth, yref + size[i] + jump, lwd = lwd, 
+           border = border, col = col)
       text(xref + bwidth + delta2 ,y = yref + jump + size[i]/2,labels = var[i],
            adj = c(0,0.5), cex = values.cex)
       jump <- size[i] + delta2 + jump
@@ -674,6 +690,7 @@ legendBarsSymbols<- function(pos = "topleft", title.txt = "Title of the legend",
 #' not (FALSE).
 #' @export
 #' @examples
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf)
 #' box()
@@ -770,6 +787,7 @@ legendPropLines<- function(pos = "topleft", title.txt = "Title of the legend",
 #' not (FALSE).
 #' @export
 #' @examples 
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf)
 #' box()
@@ -877,6 +895,7 @@ legendGradLines <- function(pos = "topleft", title.txt = "Title of the legend",
 #' styles, "c" stands for compact and "e" for extended.
 #' @export
 #' @examples
+#' library(sp)
 #' data("nuts2006")
 #' plot(nuts0.spdf)
 #' box()
@@ -910,7 +929,7 @@ legendPropTriangles<- function(pos = "topleft", title.txt, var.txt,var2.txt,
     yextent <- y2 - y1
     
     # variables internes
-    paramsize1 = 30/cex
+    paramsize1 <- 30/cex
     paramsize2 <- paramsize1*40/25
     width <- (x2 - x1) / paramsize1
     height <- width /1.5
@@ -1065,12 +1084,12 @@ legendPropTriangles<- function(pos = "topleft", title.txt, var.txt,var2.txt,
       segments(xref + xmax/2,yref-mysize/2 + yadd, xref + xmax/2 + delta1 + xmax/2 ,yref-mysize/2 + yadd)
       text(xref + xmax/2 + delta1 + xmax/2 + delta2 ,yref-mysize/2 + yadd,rValmax2,cex=values.cex,adj=c(0,0.5))
       
-      mysize <- (rLegmax2 - rLegmin2)/2 ;
+      mysize <- (rLegmax2 - rLegmin2)/2
       polygon(c(xref-mysize/2 + xmax/2,xref + xmax/2,xref+mysize/2 + xmax/2), c(yref + yadd,yref-mysize/2 + yadd,yref+yadd), col = col2)
       segments(xref + xmax/2,yref-mysize/2 + yadd, xref + xmax/2 + delta1 + xmax/2 ,yref-mysize/2 + yadd)
       text(xref + xmax/2 + delta1 + xmax/2 + delta2 ,yref-mysize/2 + yadd,round(rVal2[2],values.rnd),cex=values.cex,adj=c(0,0.5))
       
-      mysize <- rLegmin2 ;
+      mysize <- rLegmin2
       polygon(c(xref-mysize/2 + xmax/2,xref + xmax/2,xref+mysize/2 + xmax/2), c(yref+ yadd,yref-mysize/2+yadd,yref+yadd), col = col2)
       segments(xref + xmax/2,yref-mysize/2 + yadd, xref + xmax/2 + delta1 + xmax/2 ,yref-mysize/2 + yadd)
       text(xref + xmax/2 + delta1 + xmax/2 + delta2 ,yref-mysize/2 + yadd,rValmin2,cex=values.cex,adj=c(0,0.5))
